@@ -21,13 +21,11 @@
 #' clt("Uniform", 10, 10, unif_min = 10, unif_max = 20)
 #'
 #' @export
-clt <- function(
-  dist, n = 100, m = 100,
-  norm_mean = 0, norm_sd = 1,
-  binom_size = 10, binom_prob = 0.2,
-  unif_min = 0, unif_max = 1,
-  expo_rate = 1
-) {
+clt <- function(dist, n = 100, m = 100,
+                norm_mean = 0, norm_sd = 1,
+                binom_size = 10, binom_prob = 0.2,
+                unif_min = 0, unif_max = 1,
+                expo_rate = 1) {
   if (dist == "Uniform") {
     sim <- matrix(runif(n * m, min = unif_min, max = unif_max), n, m)
   } else if (dist == "Normal") {
@@ -55,7 +53,6 @@ clt <- function(
 #'
 #' @export
 plot.clt <- function(x, stat = "sum", bins = 15, ...) {
-
   if (stat == "sum") {
     sstat <- data.frame(stat = colSums(x$sim), stringsAsFactors = FALSE)
   } else {
@@ -74,7 +71,7 @@ plot.clt <- function(x, stat = "sum", bins = 15, ...) {
     labs(x = paste0("Histogram of sample #", m))
 
   plot_list[[3]] <- visualize(sstat, xvar = "stat", bins = bins, custom = TRUE) +
-    labs(x = ifelse(stat == "Sum", "Histogram of sample sums", "Histogram of sample means"))
+    labs(x = ifelse(stat == "sum", "Histogram of sample sums", "Histogram of sample means"))
 
 
   plot_list[[4]] <- visualize(sstat, xvar = "stat", type = "density", custom = TRUE) +
@@ -82,7 +79,7 @@ plot.clt <- function(x, stat = "sum", bins = 15, ...) {
       mean = mean(sstat[[1]]),
       sd = sd(sstat[[1]])
     ), color = "black", size = 1) +
-    labs(x = ifelse(stat == "Sum", "Density of sample sums", "Density of sample means"))
+    labs(x = ifelse(stat == "sum", "Density of sample sums", "Density of sample means"))
 
   patchwork::wrap_plots(plot_list, ncol = 2) + patchwork::plot_annotation(title = glue("CLT: {x$dist} distribution"))
 }
